@@ -13,20 +13,22 @@
 import sys
 from pipe2py import util
 
-RSS_FIELDS = [
-    u'mediaContentHeight',
-    u'description',
-    u'pubdate',
-    u'mediaThumbHeight',
-    u'link',
-    u'guid',
-    u'mediaThumbURL',
-    u'mediaContentType',
-    u'author',
-    u'title',
-    u'mediaContentWidth',
-    u'mediaContentURL',
-    u'mediaThumbWidth']
+#note: for some reason the config needs to match pubdate but should output pubDate
+RSS_FIELDS = {
+    u'mediaContentHeight':u'mediaContentHeight',
+    u'description':u'description',
+    u'pubdate':u'pubDate',
+    u'mediaThumbHeight':u'mediaThumbHeight',
+    u'link':u'link',
+    u'guid':u'guid',
+    u'mediaThumbURL':u'mediaThumbURL',
+    u'mediaContentType':u'mediaContentType',
+    u'author':u'author',
+    u'title':u'title',
+    u'mediaContentWidth':u'mediaContentWidth',
+    u'mediaContentURL':u'mediaContentURL',
+    u'mediaThumbWidth':u'mediaThumbWidth',
+}
 
 def transform_to_rss(item, conf):
     new = dict()
@@ -34,7 +36,7 @@ def transform_to_rss(item, conf):
         try:
             field_conf = conf[i]
             if field_conf['value']:
-                new[i] = util.get_subkey(field_conf['value'], item)
+                new[RSS_FIELDS[i]] = util.get_subkey(field_conf['value'], item)
         except KeyError:
             continue
     return new
